;; Generated package description from ada-mode.el  -*- no-byte-compile: t -*-
(define-package "ada-mode" "8.0.3.0.20230111.161811" "major-mode for editing Ada sources" '((uniquify-files "1.0.1") (wisi "4.2.0") (gnat-compiler "1.0.1") (emacs "25.3")) :commit "c3d62e181dfd1dcf02642b56b25daa7a0a9092da" :authors '(("Stephen Leake" . "stephen_leake@stephe-leake.org")) :maintainer '("Stephen Leake" . "stephen_leake@stephe-leake.org") :keywords '("languages" "ada") :url "https://www.nongnu.org/ada-mode/")
